package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.SuSubscribe;
import com.ruoyi.business.service.ISuSubscribeService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订阅管理Controller
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Controller
@RequestMapping("/business/subscribe")
public class SuSubscribeController extends BaseController
{
    private String prefix = "business/subscribe";

    @Autowired
    private ISuSubscribeService suSubscribeService;

    @RequiresPermissions("business:subscribe:view")
    @GetMapping()
    public String subscribe()
    {
        return prefix + "/subscribe";
    }

    /**
     * 查询订阅管理列表
     */
    @RequiresPermissions("business:subscribe:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(SuSubscribe suSubscribe)
    {
        startPage();
        List<SuSubscribe> list = suSubscribeService.selectSuSubscribeList(suSubscribe);
        return getDataTable(list);
    }

    /**
     * 导出订阅管理列表
     */
    @RequiresPermissions("business:subscribe:export")
    @Log(title = "订阅管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(SuSubscribe suSubscribe)
    {
        List<SuSubscribe> list = suSubscribeService.selectSuSubscribeList(suSubscribe);
        ExcelUtil<SuSubscribe> util = new ExcelUtil<SuSubscribe>(SuSubscribe.class);
        return util.exportExcel(list, "订阅管理数据");
    }

    /**
     * 新增订阅管理
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存订阅管理
     */
    @RequiresPermissions("business:subscribe:add")
    @Log(title = "订阅管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(SuSubscribe suSubscribe)
    {
        return toAjax(suSubscribeService.insertSuSubscribe(suSubscribe));
    }

    /**
     * 修改订阅管理
     */
    @RequiresPermissions("business:subscribe:edit")
    @GetMapping("/edit/{suId}")
    public String edit(@PathVariable("suId") Long suId, ModelMap mmap)
    {
        SuSubscribe suSubscribe = suSubscribeService.selectSuSubscribeBySuId(suId);
        mmap.put("suSubscribe", suSubscribe);
        return prefix + "/edit";
    }

    /**
     * 修改保存订阅管理
     */
    @RequiresPermissions("business:subscribe:edit")
    @Log(title = "订阅管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(SuSubscribe suSubscribe)
    {
        return toAjax(suSubscribeService.updateSuSubscribe(suSubscribe));
    }

    /**
     * 删除订阅管理
     */
    @RequiresPermissions("business:subscribe:remove")
    @Log(title = "订阅管理", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(suSubscribeService.deleteSuSubscribeBySuIds(ids));
    }
}
